\name{TileCalcWinScr}
\alias{TileCalcWinScr}
\title{TileCalcWinScr}
\usage{TileCalcWinScr(int, win.idx, score.function=c("mean", "trimmed",
    "median"))}
\description{Wrapper function for calculating window scores using different functions with
window indices.}
\details{Wrapper function for calculating window scores using different functions on
probe scores with window indices, a \code{list} storing window start
positions. More precisely, \code{win.idx} has the maximal number of probes
in a window as length and in its \code{i}th entry, it stores only start
positions of windows containing at least \code{(i+1)} probes. In case of
short but numerous windows, the window scores can be calculated very
efficiently by use of optimized \code{vector} operations. Otherwise, please
consider using \code{\link{TileCalcWinScr2}} instead.}
\value{A \code{numeric} \code{vector} containing the calculated window
scores for each possible start position. Note that windows of length
zero are not supported and hence treated as windows of length one.
Moreover, probe scores with the value \code{NA} are excluded from
the calculation.}
\keyword{internal}
\arguments{\item{int}{A \code{numeric} \code{vector} containing one or more probe
scores (i.e. intensities or log-fold changes).}
\item{win.idx}{A \code{list} with the maximal number of probes in a window
as its length. In entry \code{i}, it stores only start positions of
windows containing at least \code{(i+1)} probes.}
\item{score.function}{Function to calculate windows scores over the
\code{log2}-intensities or \code{log2}-fold changes of the
corresponding probes, i.e., arithmetic average
(\code{score.function} = "mean"), arithmetic mean trimmed by the
minimal and maximal value (\code{score.function} = "trimmed"),
or the median (\code{score.function} = "median"). Note that the
definition of trimmed mean differs from the common one with given
percentile ranges. Moreover, the resulting scores with trimmed
mean may only differ from the mean only in case of windows that
contain more than two probes. The latter two scoring functions
are recommended due to their higher robustness against outliers.
However, due to the higher calculation costs, the running time
increases by selecting "trimmed" or "median". Note that the function
is given as \code{character}.}}
